 /*
 * file      : build_buf.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 - 2011 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 * 
 * This file is part of BASEBUILD.
 * 
 * BASEBUILD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * BASEBUILD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with BASEBUILD.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <glib/gstdio.h>

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <stdlib.h>

#include "../libbasebuild/libbasebuild.h"
#include "callbacks.h"
#include "build.h"

/*
	|-- ABOUT-NLS
	|-- AUTHORS
	|-- README
	|-- COPYING
	|-- INSTALL
	|-- NEWS
	|-- ChangeLog
	|-- configure.in
	|-- configure.scan
	|-- Makefile.am
	|-- glade
	|   |-- basebuild.glade
	|-- libbasebuild
	|   |-- combo.c
	|   |-- libbasebuild.h
	|   |-- Makefile.am
	|   |-- utils.c
	|-- man
	|   |-- basebuild.1.gz
	|   |-- compilate_manpage.txt
	|   |-- Makefile.am
	|-- menu
	|   |-- basebuild.desktop
	|   |-- Makefile.am
	|-- pixmaps
	|   |-- basebuild.desktop
	|   |-- basebuild.png
	|   |-- Makefile.am
	|-- po
	|   |-- basebuild.pot
	|   |-- en.po
	|   |-- fr.po
	|   |-- POTFILES.in
	|-- src
	|   |-- build_buf.c
	|   |-- build.c
	|   |-- build.h
	|   |-- callbacks.c
	|   |-- callbacks.h
	|   |-- configuser.c
	|   |-- configuser.h
	|   |-- def_src.c
	|   |-- def_src.h
	|   |-- fileselect.c
	|   |-- fileselect.h
	|   |-- global.h
	|   |-- main.c
	|   |-- Makefile.am
	|   |-- proto.c
	|   |-- proto.h
	|   |-- translate.c
	|   |-- translate.h
	|   |-- view.c
	|   |-- view.h
	|   |-- win_about.c
	|   |-- win_about.h
	|   |-- win_info.c
	|   |-- win_info.h

*/

extern VAR_CALLBACKS VarCallbacks;
extern VAR_BUILD VarBuild;



// MAKEFILE.AM
// 
void BuildBuf_create_makefile_am (void)
{
	GList		*List = NULL;
	VAR_BUILD_SRC	*VarBuildSrc = NULL;
	
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrMakefileAm != NULL) {
		g_string_free (VarBuild.GstrMakefileAm, TRUE);
		VarBuild.GstrMakefileAm = NULL;
	}
	// INIT GString
	VarBuild.GstrMakefileAm = g_string_new (NULL);

	g_string_append_printf (VarBuild.GstrMakefileAm, "#\n# Makefile.am with BaseBuild\n#\n");
	g_string_append_printf (VarBuild.GstrMakefileAm, "SUBDIRS = ");
	if (TRUE == VarBuild.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "po ");
	}
	if (TRUE == VarBuild.Bool_dossier_lib_statique) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "%s ", VarBuild.NameLib);
	}

	List = g_list_first (VarBuild.ListPathSrc);
	while (List) {
		if (NULL != (VarBuildSrc = (VAR_BUILD_SRC *)List->data)) {
			g_string_append_printf (VarBuild.GstrMakefileAm, "%s ", VarBuildSrc->Name);
		}
		List = g_list_next (List);
	}

	if (TRUE == VarBuild.Bool_dossier_manpage) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "man ");
	}
	if (TRUE == VarBuild.Bool_dossier_pixmaps) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "pixmaps ");
	}
	if (TRUE == VarBuild.Bool_dossier_menu) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "menu ");
	}
	if (TRUE == VarBuild.Bool_dossier_mime) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "mime ");
	}
	if (TRUE == VarBuild.Bool_dossier_glade) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "glade ");
	}
	g_string_append_printf (VarBuild.GstrMakefileAm, "\nACLOCAL_AMFLAGS = -I m4\n");
	g_string_append_printf (VarBuild.GstrMakefileAm, "EXTRA_DIST = ");
	if (TRUE == VarBuild.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "config.rpath m4/ChangeLog\n");
	}
}
// CONFIGURE.IN
// 
void BuildBuf_create_configure_in (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrConfigureIn != NULL) {
		g_string_free (VarBuild.GstrConfigureIn, TRUE);
		VarBuild.GstrConfigureIn = NULL;
	}
	// INIT GString
	VarBuild.GstrConfigureIn = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrConfigureIn, "#\n# configure.in with BaseBuild\n#\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "#                                               -*- Autoconf -*-\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "# Process this file with autoconf to produce a configure script.\n");
	
	/*
	g_string_append_printf (VarBuild.GstrConfigureIn, "\nAC_PREREQ(2.61)\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_INIT(%s, %d.%d.%d)\n",
					gtk_entry_get_text (GTK_ENTRY (VarCallbacks.Adr_name_project)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_A)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_B)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_C))
					);
					
					AC_INIT([xcfa],
						[4.2.2~beta12],
						[http://www.xcfa.tuxfamily.org/],
						[xcfa],
						[http://www.xcfa.tuxfamily.org/])
					*/
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_INIT([%s],\n\t[%d.%d.%d],\n\t[http://www.xcfa.tuxfamily.org/],\n\t[%s],\n\t[http://www.xcfa.tuxfamily.org/])\n",
					gtk_entry_get_text (GTK_ENTRY (VarCallbacks.Adr_name_project)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_A)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_B)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_C)),
					gtk_entry_get_text (GTK_ENTRY (VarCallbacks.Adr_name_project))
					);
					
					
	g_string_append_printf (VarBuild.GstrConfigureIn, "AM_INIT_AUTOMAKE\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CONFIG_SRCDIR([src/main.c])\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CONFIG_HEADER([config.h])\n");

	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Checks for programs.\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_CXX\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_CC\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_CPP\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_INSTALL\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "# AC_PROG_LN_S\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_MAKE_SET\n");
	if (TRUE == VarBuild.Bool_dossier_lib_statique) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "# AM_PROG_LIBTOOL\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_RANLIB\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AM_PROG_CC_C_O\n");
		
		g_string_append_printf (VarBuild.GstrConfigureIn, "\nAC_DEFINE(ENABLE_STATIC_LIBRARY,1,[Define for enable static library])\n");
	}

	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Enable silent rules if supported\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "m4_ifdef([AM_SILENT_RULES], [AM_SILENT_RULES([yes])])\n");

	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Set PREFIX: ./configure  OR ./configure --prefix=/usr\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_SUBST(INSTALL_PREFIX)\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PREFIX_DEFAULT(/usr/local)\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "if [[ $prefix = \"NONE\" ]] ; then\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_DEFINE(INSTALL_PREFIX, \"/usr/local\",\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "\t\t[define as prefix where %s is installed])\n", VarBuild.NameProject);
	g_string_append_printf (VarBuild.GstrConfigureIn, "else\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_DEFINE_UNQUOTED(INSTALL_PREFIX, \"$prefix\")\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "fi\n");
	
	if (TRUE == VarBuild.Bool_lib_gtk) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Set used name package glade: *.glade\n");
		g_string_append_printf (VarBuild.GstrConfigureIn,
					"AC_DEFINE(PACKAGE_NAME_GLADE, \"%s.glade\", [define as package name of glade])\n", VarBuild.NameProject);
	}
	
	if (TRUE == VarBuild.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "\n# nls support\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_MSG_CHECKING(for nls mode support)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "BASEBUILD_LANG=\"en en_GB fr de it\"\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_ARG_ENABLE(nls, , [\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "if test \"$enableval\" = \"yes\"; then\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tALL_LINGUAS=$BASEBUILD_LANG\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_MSG_RESULT(yes)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAM_GNU_GETTEXT([external])\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_DEFINE(ENABLE_NLS,1,[Define for NLS support])\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "else\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_MSG_RESULT(no)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tALL_LINGUAS=""\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tUSE_NLS=\"no\"\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "fi\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "], [\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tALL_LINGUAS=$BASEBUILD_LANG\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_MSG_RESULT(yes)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAM_GNU_GETTEXT([external])\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_DEFINE(ENABLE_NLS,1,[Define for NLS support])\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "])\n\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "GETTEXT_PACKAGE=[$PACKAGE]\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_SUBST(GETTEXT_PACKAGE)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_DEFINE_UNQUOTED([GETTEXT_PACKAGE],[\"$GETTEXT_PACKAGE\"],[gettext domain])\n");
	}
	
	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Checks for libraries.\n");
	if (TRUE == VarBuild.Bool_dossier_lib_statique) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CHECK_LIB([%s], [libH_print_mess])\n", VarBuild.NameLib);
	}
	
	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Checks for header files.\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_HEADER_STDC\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CHECK_HEADERS([libintl.h stdlib.h string.h unistd.h])\n");
	
	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Checks for typedefs, structures, and compiler characteristics.\n");

	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Checks for library functions.\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_FUNC_STAT\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CHECK_FUNCS([setlocale strchr strrchr])\n");
	
	{
		gchar	*Buf_debug =
	
		"\n#\n"
		"# debug and ansi support\n"
		"#\n"
		"AC_ARG_ENABLE(debug_pg, AC_HELP_STRING([--disable-debug-pg], [Enable debug mode (default=disable)]),,enable_debug_pg=no)\n"
		"AC_ARG_ENABLE(debug, AC_HELP_STRING([--disable-debug], [Disable debug mode (default=disable)]),,enable_debug=no)\n"
		"AC_ARG_ENABLE(ansi,  AC_HELP_STRING([--disable-ansi],  [Enable ansi (default=enabled)]),,enable_ansi=no)\n"
		"\n"
		"AC_MSG_CHECKING(for debug mode request)\n"
		"if test \"$enable_debug\" = \"yes\"; then\n"
		" 	AC_MSG_RESULT(yes)\n"
		"	AC_DEFINE(DEBUG,1,[Define for debug support])\n"
		"	AC_MSG_CHECKING(With ansi compilate)\n"
		"	if test \"$enable_ansi\" = \"yes\"; then\n"
		"		AC_MSG_RESULT(yes)\n"
		"		AC_DEFINE(ENABLE_ANSI,1,[Define With ansi compilate])\n"
		"		AC_MSG_CHECKING(With enable_debug_pg)\n"
		"		if test \"$enable_debug_pg\" = \"yes\"; then\n"
		"			AC_MSG_RESULT(yes)\n"
		"			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=yes, enable_ansi=yes, enable_debug_pg=yes\"\n"
		"			echo \"*** CFLAGS=-pg -g -O2 -Wall -ansi -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-pg -g -O2 -Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		else\n"
		"			AC_MSG_RESULT(no)\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=yes, enable_ansi=yes, enable_debug_pg=no\"\n"
		"			echo \"*** CFLAGS=-g -O2 -Wall -ansi -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-g -O2 -Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		fi\n"
		"	else\n"
		"		AC_MSG_RESULT(no)\n"
		"		AC_MSG_CHECKING(With enable_debug_pg)\n"
		"		if test \"$enable_debug_pg\" = \"yes\"; then\n"
		"			AC_MSG_RESULT(yes)\n"
		"			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=yes, enable_ansi=no, enable_debug_pg=yes\"\n"
		"			echo \"*** CFLAGS=-pg -g -O2 -Wall -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-pg -g -O2 -Wall -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		else\n"
		"			AC_MSG_RESULT(no)\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=yes, enable_ansi=no, enable_debug_pg=no\"\n"
		"			echo \"*** CFLAGS=-g -O2 -Wall -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-g -O2 -Wall -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		fi\n"
		"	fi\n"
		"else\n"
		" 	AC_MSG_RESULT(no)\n"
		"	AC_MSG_CHECKING(With ansi compilate)\n"
		" 	if test \"$enable_ansi\" = \"yes\"; then\n"
		" 		AC_MSG_RESULT(yes)\n"
		"		AC_DEFINE(ENABLE_ANSI,1,[Define With ansi compilate])\n"
		"		AC_MSG_CHECKING(With enable_debug_pg)\n"
		"		if test \"$enable_debug_pg\" = \"yes\"; then\n"
		"			AC_MSG_RESULT(yes)\n"
		"			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=no, enable_ansi=yes, enable_debug_pg=yes\"\n"
		"			echo \"*** CFLAGS=-pg -Wall -ansi -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-pg -Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		else\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=no, enable_ansi=yes, enable_debug_pg=no\"\n"
		"			echo \"*** CFLAGS=-Wall -ansi -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		fi\n"
		"	else\n"
		"		AC_MSG_RESULT(no)\n"
		"		AC_MSG_CHECKING(With enable_debug_pg)\n"
		"		if test \"$enable_debug_pg\" = \"yes\"; then\n"
		"			AC_MSG_RESULT(yes)\n"
		"			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=no, enable_ansi=no, enable_debug_pg=yes\"\n"
		"			echo \"*** CFLAGS=-pg -Wall -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-pg -Wall -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		else\n"
		"			AC_MSG_RESULT(no)\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=no, enable_ansi=no, enable_debug_pg=no\"\n"
		"			echo \"*** CFLAGS=-Wall -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-Wall -O3 -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		fi\n"
		"	fi\n"
		"fi\n"
		"\n";
		
		g_string_append_printf (VarBuild.GstrConfigureIn, Buf_debug);
	}

	if (TRUE == VarBuild.Bool_lib_gtk || VarBuild.Bool_lib_gthread) {
		
		g_string_append_printf (VarBuild.GstrConfigureIn, "\n#\n# prerequis pour gtk\n#\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "pkg_modules=\"");
		if (TRUE == VarBuild.Bool_lib_gtk)
			g_string_append_printf (VarBuild.GstrConfigureIn, "gtk+-2.0 glib-2.0 ");
		if (TRUE == VarBuild.Bool_lib_gthread)
			g_string_append_printf (VarBuild.GstrConfigureIn, "gthread-2.0 ");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\"\n");
		
		g_string_append_printf (VarBuild.GstrConfigureIn, "PKG_CHECK_MODULES(PACKAGE, [$pkg_modules])\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_SUBST(PACKAGE_CFLAGS)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_SUBST(PACKAGE_LIBS)\n");
		
		if (TRUE == VarBuild.Bool_lib_gthread) {
			g_string_append_printf (VarBuild.GstrConfigureIn, "\n#\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "# prerequis pour pthread\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "#\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CHECK_LIB([pthread], [pthread_create],,\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "[\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"***\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"*** Error! You need to have pthread around.\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"***\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"*** Install libc6\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"*** Install libc6-dev\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"***\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  exit -1\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "])\n");
		}
	}


	{
		GString	*GstrSrc = NULL;
		GList	*List = NULL;
		VAR_BUILD_SRC *VarBuildSrc = NULL;
		gchar	*StrLib = g_strdup_printf ("%s/Makefile\n", VarBuild.NameLib);
		
		GstrSrc = g_string_new (NULL);
		List = g_list_first (VarBuild.ListPathSrc);
		while (List) {
			if (NULL != (VarBuildSrc = (VAR_BUILD_SRC *)List->data)) {
				g_string_append_printf (GstrSrc, "%s/Makefile\n", VarBuildSrc->Name);
			}
			List = g_list_next (List);
		}
		
		g_string_append_printf (VarBuild.GstrConfigureIn, "\nAC_CONFIG_FILES([\n%s%sMakefile\n%s%s%s%s%s%s])\n",
							VarBuild.Bool_dossier_po ? "po/Makefile.in\n" : "",
							// VarBuild.Bool_dossier_lib_statique ? "lib/Makefile\n" : "",
							VarBuild.Bool_dossier_lib_statique ? StrLib : "",
							GstrSrc->str,
							VarBuild.Bool_dossier_manpage ? "man/Makefile\n" : "",
							VarBuild.Bool_dossier_pixmaps ? "pixmaps/Makefile\n" : "",
							VarBuild.Bool_dossier_menu ? "menu/Makefile\n" : "",
							VarBuild.Bool_dossier_mime ? "mime/Makefile\n" : "",
							VarBuild.Bool_dossier_glade ? "glade/Makefile\n" : ""
							);
		g_free (StrLib);
		StrLib = NULL;
		g_string_free (GstrSrc, TRUE);
	}
	
	
	g_string_append_printf (VarBuild.GstrConfigureIn, "\nAC_OUTPUT\n");

	g_string_append_printf (VarBuild.GstrConfigureIn, "\necho \"\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "=================================================================\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  configure.in product with BaseBuild: \n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "      http://www.xcfa.tuxfamily.org/\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "=================================================================\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Configuration for $PACKAGE $VERSION :\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "=================================================================\n\n");
        g_string_append_printf (VarBuild.GstrConfigureIn, "  Host System Type ................ : $host\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  HosName ......................... : `hostname`\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Compiler ........................ : $CC $CPPFLAGS\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Linker .......................... : $CC $LDFLAGS");
	if (TRUE == VarBuild.Bool_lib_gtk || VarBuild.Bool_lib_gthread) {
		g_string_append_printf (VarBuild.GstrConfigureIn, " $LIBS\n");
	}
	else {
		g_string_append_printf (VarBuild.GstrConfigureIn, "\n");
	}
	if (TRUE == VarBuild.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "  NLS/gettext ..................... : $USE_NLS\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "  ALL_LINGUAS ..................... : $ALL_LINGUAS\n");
	}
	if (TRUE == VarBuild.Bool_lib_gtk || VarBuild.Bool_lib_gthread) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "  GTK+ version .................... : `pkg-config --modversion gtk+-2.0`\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "  GLIB version .................... : `pkg-config --modversion glib-2.0`\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "  GTHREAD version ................. : `pkg-config --modversion gthread-2.0`\n");
	}
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Debug mode g .................... : $enable_debug\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Debug mode pg ................... : $enable_debug_pg\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  WITH ANSI COMPILATE ............. : $enable_ansi\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  CFLAGS .......................... : $CFLAGS\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  INSTALL ......................... : $prefix/bin/%s\n\n", VarBuild.NameProject);
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Options parameters:\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  -------------------\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  by default:\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--disable-debug                             No debug support\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--disable-debug-pg                          No debug support with gprof\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--disable-ansi                              No define ansi for probleme compilate\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Options is:\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--enable-debug      #define DEBUG 1         Define for debug: -g\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--enable-debug-pg   #define DEBUG_PG 1      Define for debug support with gprof: -pg\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--enable-ansi       #define ENABLE_ANSI 1   Define With ansi compilate\n\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Now type 'make' to build $PACKAGE $VERSION,\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  and then type (under root) 'make install' for installation.\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "\"\n");
}
// SRC/MAKEFILE.AM
// 
void BuildBuf_create_src_all_makefile_am (void)
{
	GList		*List = NULL;
	VAR_BUILD_SRC	*VarBuildSrc = NULL;
	
	List = g_list_first (VarBuild.ListPathSrc);
	while (List) {
		if (NULL != (VarBuildSrc = (VAR_BUILD_SRC *)List->data)) {
			// REMOVE BUFFER IF EXIST
			if (VarBuildSrc->GstrSrcMakefileAm != NULL) {
				g_string_free (VarBuildSrc->GstrSrcMakefileAm, TRUE);
				VarBuildSrc->GstrSrcMakefileAm = NULL;
			}
			// INIT GString
			VarBuildSrc->GstrSrcMakefileAm = g_string_new (NULL);
			
			g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "#\n# %s/Makefile.am with BaseBuild\n#\n", VarBuildSrc->Name);
			g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");

			if (TRUE == VarBuild.Bool_lib_gtk) {
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "\nINCLUDES = \\\n");
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "   -DPACKAGE_DATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "   -DPACKAGE_LOCALE_DIR=\\\"\"$(prefix)/$(DATADIRNAME)/locale\"\\\" \\\n");
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \\\n", VarBuild.NameProject);
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "	@PACKAGE_CFLAGS@\n");
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "\nAM_CFLAGS = @PACKAGE_CFLAGS@ \\\n");
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "   -DDATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "   -DLOCALE_DIR=\\\"\"$(datadir)/locale\"\\\" \\\n");
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \n", VarBuild.NameProject);
			}
			g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "\nbin_PROGRAMS=%s\n", VarBuildSrc->Exec);
			// if (TRUE == VarBuild.Bool_lib_gtk && TRUE == VarBuild.Bool_dossier_po) {
			if (TRUE == VarBuild.Bool_import_glade_translate) {
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "%s_SOURCES=main.c translate.c global.h\n", VarBuildSrc->Exec);
			}
			else {
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "%s_SOURCES=main.c global.h\n", VarBuildSrc->Exec);
			}
			if (TRUE == VarBuild.Bool_dossier_lib_statique) {
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "\n%s_CPPFLAGS=-I${top_srcdir}/%s\n", VarBuildSrc->Exec, VarBuild.NameLib);
			}
			if (TRUE == VarBuild.Bool_dossier_po) {
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "\ndatadir = @datadir@\n");
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "localedir = $(datadir)/locale\n");
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "DEFS = -DLOCALEDIR=\"$(localedir)\" @DEFS@\n");
			}
			if (TRUE == VarBuild.Bool_lib_gtk || TRUE == VarBuild.Bool_dossier_lib_statique || TRUE == VarBuild.Bool_dossier_po) {
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "\n%s_LDADD =", VarBuildSrc->Exec);
				if (TRUE == VarBuild.Bool_lib_gtk) {
					g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "@PACKAGE_LIBS@");
				}
				if (TRUE == VarBuild.Bool_dossier_po) {
					g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, " $(INTLLIBS)");
				}
				if (TRUE == VarBuild.Bool_dossier_lib_statique) {
					g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, " ${top_builddir}/%s/%s.a", VarBuild.NameLib, VarBuild.NameLib);
				}
				g_string_append_printf (VarBuildSrc->GstrSrcMakefileAm, "\n");
			}
		}
		List = g_list_next (List);
	}
}
// MAN/MAKEFILE.AM
// 
void BuildBuf_create_man_makefile_am (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrManMakefileAm != NULL) {
		g_string_free (VarBuild.GstrManMakefileAm, TRUE);
		VarBuild.GstrManMakefileAm = NULL;
	}
	// INIT GString
	VarBuild.GstrManMakefileAm = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrManMakefileAm, "#\n# man/Makefile.am with BaseBuild\n#\n");
	g_string_append_printf (VarBuild.GstrManMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	g_string_append_printf (VarBuild.GstrManMakefileAm, "man1_MANS = %s.1.gz\n", VarBuild.NameProject);
	g_string_append_printf (VarBuild.GstrManMakefileAm, "EXTRA_DIST = compilate_manpage.txt %s.1.gz\n", VarBuild.NameProject);
}
// LIB/MAKEFILE.AM
// 
void BuildBuf_create_lib_makefile_am (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrLibMakefileAm != NULL) {
		g_string_free (VarBuild.GstrLibMakefileAm, TRUE);
		VarBuild.GstrLibMakefileAm = NULL;
	}
	// INIT GString
	VarBuild.GstrLibMakefileAm = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrLibMakefileAm, "#\n# %s/Makefile.am with BaseBuild\n#\n", VarBuild.NameLib);
	g_string_append_printf (VarBuild.GstrLibMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	if (TRUE == VarBuild.Bool_lib_gtk) {
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "\nINCLUDES = \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DPACKAGE_DATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DPACKAGE_LOCALE_DIR=\\\"\"$(prefix)/$(DATADIRNAME)/locale\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \\\n", VarBuild.NameProject);
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "	@PACKAGE_CFLAGS@\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "\nAM_CFLAGS = @PACKAGE_CFLAGS@ \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DDATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DLOCALE_DIR=\\\"\"$(datadir)/locale\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \n", VarBuild.NameProject);
	}
	g_string_append_printf (VarBuild.GstrLibMakefileAm, "noinst_LIBRARIES=%s.a\n", VarBuild.NameLib);
	g_string_append_printf (VarBuild.GstrLibMakefileAm, "%s_a_SOURCES=lib.c lib.h\n", VarBuild.NameLib);
}
// PIXMAPS/MAKEFILE.AM
// 
void BuildBuf_create_pixmaps_makefile_am (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrPixmapsMakefileAm != NULL) {
		g_string_free (VarBuild.GstrPixmapsMakefileAm, TRUE);
		VarBuild.GstrPixmapsMakefileAm = NULL;
	}
	// INIT GString
	VarBuild.GstrPixmapsMakefileAm = g_string_new (NULL);

	g_string_append_printf (VarBuild.GstrPixmapsMakefileAm, "#\n# pixmaps/Makefile.am with BaseBuild\n#\n");
	g_string_append_printf (VarBuild.GstrPixmapsMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	g_string_append_printf (VarBuild.GstrPixmapsMakefileAm, "pixmaps_DATA = test%s.png\n", VarBuild.NameProject);
	g_string_append_printf (VarBuild.GstrPixmapsMakefileAm, "pixmapsdir = $(datadir)/pixmaps\n");
	g_string_append_printf (VarBuild.GstrPixmapsMakefileAm, "EXTRA_DIST = $(pixmaps_DATA)\n");
}
// MENU/MAKEFILE.AM
// 
void BuildBuf_create_menu_makefile_am (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrMenuMakefileAm != NULL) {
		g_string_free (VarBuild.GstrMenuMakefileAm, TRUE);
		VarBuild.GstrMenuMakefileAm = NULL;
	}
	// INIT GString
	VarBuild.GstrMenuMakefileAm = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrMenuMakefileAm, "#\n# menu/Makefile.am with BaseBuild\n#\n");
	g_string_append_printf (VarBuild.GstrMenuMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	g_string_append_printf (VarBuild.GstrMenuMakefileAm, "menu_DATA = %s.desktop\n", VarBuild.NameProject);
	g_string_append_printf (VarBuild.GstrMenuMakefileAm, "menudir = $(datadir)/applications\n");
	g_string_append_printf (VarBuild.GstrMenuMakefileAm, "EXTRA_DIST = $(menu_DATA)\n");
}
// MIME/MAKEFILE.AM
// 
void BuildBuf_create_mime_makefile_am (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrMimeMakefileAm != NULL) {
		g_string_free (VarBuild.GstrMimeMakefileAm, TRUE);
		VarBuild.GstrMimeMakefileAm = NULL;
	}
	// INIT GString
	VarBuild.GstrMimeMakefileAm = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrMimeMakefileAm, "#\n# mime/Makefile.am with BaseBuild\n#\n");
	g_string_append_printf (VarBuild.GstrMimeMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	g_string_append_printf (VarBuild.GstrMimeMakefileAm, "EXTRA_DIST = %s\n", VarBuild.NameProject);
	g_string_append_printf (VarBuild.GstrMimeMakefileAm, "mime_DATA = %s\n", VarBuild.NameProject);
	g_string_append_printf (VarBuild.GstrMimeMakefileAm, "mimedir = $(DESTDIR)/$(libdir)/mime/packages\n");
}
// GLADE/MAKEFILE.AM
// 
void BuildBuf_create_glade_makefile_am (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrGladeMakefileAm != NULL) {
		g_string_free (VarBuild.GstrGladeMakefileAm, TRUE);
		VarBuild.GstrGladeMakefileAm = NULL;
	}
	// INIT GString
	VarBuild.GstrGladeMakefileAm = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "#\n# glade/Makefile.am with BaseBuild\n#\n");
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "EXTRA_DIST = %s.glade\n", VarBuild.NameProject);
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "gladedir = $(datadir)/%s/glade\n", VarBuild.NameProject);
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "glade_DATA = %s.glade\n", VarBuild.NameProject);
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "\nuninstall:\n");
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "\trm -rf \"$(DESTDIR)$(datadir)/%s/\";\n", VarBuild.NameProject);
}














