 /*
 * file      : proto.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 - 2011 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 * 
 * This file is part of BASEBUILD.
 * 
 * BASEBUILD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * BASEBUILD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with BASEBUILD.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>

#include "global.h"
#include "../libbasebuild/libbasebuild.h"
#include "build.h"
#include "proto.h"


extern VAR_BUILD VarBuild;


typedef enum {				// THE SIGNAL MUST BE DEFINED HERE
	SIGNAL_NONE = 0,
	SIGNAL_ACTIVATE,		// signal name="activate"
	SIGNAL_BUTTON_PRESS_EVENT,	// signal name="button_press_event"
	SIGNAL_BUTTON_RELEASE_EVENT,	// signal name="button_release_event"
	SIGNAL_CHANGED,			// signal name="changed"
	SIGNAL_CLICKED,			// signal name="clicked"
	SIGNAL_CLOSE,			// signal name="close"
	SIGNAL_DELETE_EVENT,		// signal name="delete_event"
	SIGNAL_DESTROY_EVENT,		// signal name="destroy_event"
	SIGNAL_DESTROY,			// signal name="destroy"
	SIGNAL_ENTER_NOTIFY_EVENT,	// signal name="enter_notify_event"
	SIGNAL_EVENT,			// signal name="event"
	SIGNAL_EVENT_AFTER,		// signal name="event_after"
	SIGNAL_EXPOSE_EVENT,		// signal name="expose_event"
	SIGNAL_KEY_PRESS_EVENT,		// signal name="key_press_event"
	SIGNAL_KEY_RELEASE_EVENT,	// signal name="key_release_event"
	SIGNAL_LEAVE_NOTIFY_EVENT,	// signal name="leave_notify_event"
	SIGNAL_MAP_EVENT,		// signal name="map_event"
	SIGNAL_MOTION_NOTIFY_EVENT,	// signal name="motion_notify_event"
	SIGNAL_REALIZE,			// signal name="realize"
	SIGNAL_RESPONSE,		// signal name="response"
	SIGNAL_DRAGNDROP_RECEVEID,	// signal name="drag_data_received"
	SIGNAL_TOGGLED,			// class="toggled"
	SIGNAL_SWITCH_PAGE,		// signal name="switch_page"
	SIGNAL_VALUE_CHANGED		// signal name="value_changed"
} TYPE_SIGNAL;

typedef struct {
	gchar		*Signal;	// ACTIVATE | CHANGED ...
	gchar		*Handler;	// Nom du handler
	TYPE_SIGNAL	TypeSignal;	// 
} STRUCT_SIGNAL;


typedef enum {				// TYPE OF CLASS MUST BE DEFINED HERE
	CLASS_NONE = 0,
	CLASS_GTK_ABOUTDIALOG,		// class="GtkAboutDialog"
	CLASS_GTK_ALIGMENT,		// class="GtkAlignment"
	CLASS_GTK_BUTTON,		// class="GtkButton"
	CLASS_GTK_CHECKBUTTON,		// class="GtkCheckButton"
	CLASS_GTK_COMBOBOX,		// class="GtkComboBox"
	CLASS_GTK_COMBOBOXENTRY,	// class="GtkComboBoxEntry"
	CLASS_GTK_DIALOG,		// class="GtkDialog"
	CLASS_GTK_DRAWINGAREA,		// class="GtkDrawingArea"
	CLASS_GTK_ENTRY,		// class="GtkEntry"
	CLASS_GTK_EVENTBOX,		// class="GtkEventBox"
	CLASS_GTK_EXPANDER,		// class="GtkExpander"
	CLASS_GTK_IMAGE,		// class="GtkImage"
	CLASS_GTK_IMAGEMENUITEM,	// class="GtkImageMenuItem"
	CLASS_GTK_FRAME,		// class="GtkFrame"
	CLASS_GTK_HBOX,			// class="GtkHBox"
	CLASS_GTK_LABEL,		// class="GtkLabel"
	CLASS_GTK_LINKBUTTON,		// class="GtkLinkButton"
	CLASS_GTK_MENUBAR,		// class="GtkMenuBar"
	CLASS_GTK_MENUITEM,		// class="GtkMenuItem"
	CLASS_GTK_MENU,			// class="GtkMenu"
	CLASS_GTK_NOTEBOOK,		// class="GtkNotebook"
	CLASS_GTK_PROGRESSBAR,		// class="GtkProgressBar"
	CLASS_GTK_RADIOBUTTON,		// class="GtkRadioButton"
	CLASS_GTK_SEPARATORMENUITEM,	// class="GtkSeparatorMenuItem"
	CLASS_GTK_SCROLLEWINDOW,	// class="GtkScrolledWindow"
	CLASS_GTK_SPINBUTTON,		// class="GtkSpinButton"
	CLASS_GTK_TABLE,		// class="GtkTable"
	CLASS_GTK_TEXTVIEW,		// class="GtkTextView"
	CLASS_GTK_TOGGLEBUTTON,		// class="GtkToggleButton"
	CLASS_GTK_VBOX,			// class="GtkVBox"
	CLASS_GTK_VIEWPORT,		// class="GtkViewport"
	CLASS_GTK_WINDOW		// class="GtkWindow"
} TYPE_CLASS;

typedef struct {
	gchar		*Object;	// GTK_BUTTON | GTK_WINDOW ...
	gchar		*Id;		// Nom de l' Id
	TYPE_CLASS	TypeClass;	// 
	GList		*ListSignal;	// LISTE DE STRUCT_SIGNAL POUR STRUCT_CLASS
} STRUCT_CLASS;

GList	*ListClass = NULL;		// LISTE DES 'STRUCT_CLASS'

VAR_PROTO VarProto = {
		NULL,			// GstrMain
		NULL,			// GstrTranslate
		FALSE,			// BoolTranslateOk
		NULL,			// PathNameFileGlade
		FALSE			// BoolOk
		};

typedef struct {

	 TYPE_CLASS	TypeClass;
	 TYPE_SIGNAL	TypeSignal;
	 gboolean	ReturnBoolean;
	 gchar		*ParamFunction;
	 
} PROTO_STRUCT;
PROTO_STRUCT ProtoStruct [] = {

{ CLASS_NONE,			SIGNAL_NONE,			FALSE,	"// [ CLASS UNDEFINED ] " },

{ CLASS_GTK_ABOUTDIALOG,	SIGNAL_DESTROY_EVENT,		TRUE,	"( GtkWidget *widget, GdkEvent *event, gpointer user_data )" },
{ CLASS_GTK_ABOUTDIALOG,	SIGNAL_DELETE_EVENT,		TRUE,	"( GtkWidget *widget, GdkEvent *event, gpointer user_data )" },
{ CLASS_GTK_ABOUTDIALOG,	SIGNAL_RESPONSE,		FALSE,	"( void )" },
{ CLASS_GTK_ABOUTDIALOG,	SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_ABOUTDIALOG :" },

{ CLASS_GTK_ALIGMENT,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_ALIGMENT " },

{ CLASS_GTK_BUTTON,		SIGNAL_ENTER_NOTIFY_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventCrossing *event, gpointer user_data )" },
{ CLASS_GTK_BUTTON,		SIGNAL_LEAVE_NOTIFY_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventCrossing *event, gpointer user_data )" },
{ CLASS_GTK_BUTTON,		SIGNAL_CLICKED,			FALSE,	"( GtkButton *button, gpointer user_data )" },
{ CLASS_GTK_BUTTON,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_BUTTON,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_BUTTON :" },

{ CLASS_GTK_CHECKBUTTON,	SIGNAL_CLICKED,			FALSE,	"( GtkButton *button, gpointer user_data )" },
{ CLASS_GTK_CHECKBUTTON,	SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_CHECKBUTTON,	SIGNAL_ENTER_NOTIFY_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventCrossing *event, gpointer user_data )" },
{ CLASS_GTK_CHECKBUTTON,	SIGNAL_LEAVE_NOTIFY_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventCrossing *event, gpointer user_data )" },
{ CLASS_GTK_CHECKBUTTON,	SIGNAL_TOGGLED,			FALSE,	"( GtkToggleButton *togglebutton, gpointer user_data )" },
{ CLASS_GTK_CHECKBUTTON,	SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_CHECKBUTTON :" },

{ CLASS_GTK_COMBOBOX,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_COMBOBOX,		SIGNAL_CHANGED,			FALSE,	"( GtkComboBox *combobox, gpointer user_data )" },
{ CLASS_GTK_COMBOBOX,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_COMBOBOX :" },

{ CLASS_GTK_COMBOBOXENTRY,	SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_COMBOBOXENTRY,	SIGNAL_CHANGED,			FALSE,	"( GtkComboBox *combobox, gpointer user_data )" },
{ CLASS_GTK_COMBOBOXENTRY,	SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_COMBOBOXENTRY :" },

{ CLASS_GTK_DIALOG,		SIGNAL_DELETE_EVENT,		TRUE,	"( GtkWidget *widget, GdkEvent *event, gpointer user_data )" },
{ CLASS_GTK_DIALOG,		SIGNAL_DESTROY_EVENT,		TRUE,	"( GtkWidget *widget, GdkEvent *event, gpointer user_data )" },
{ CLASS_GTK_DIALOG,		SIGNAL_CLOSE,			FALSE,	"( GtkDialog *Dialog, gpointer data )" },
{ CLASS_GTK_DIALOG,		SIGNAL_MAP_EVENT,		FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_DIALOG,		SIGNAL_RESPONSE,		FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_DIALOG,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_DIALOG :" },

{ CLASS_GTK_DRAWINGAREA,	SIGNAL_BUTTON_PRESS_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventButton *event, gpointer user_data )" },
{ CLASS_GTK_DRAWINGAREA,	SIGNAL_BUTTON_RELEASE_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventButton *event, gpointer user_data )" },
{ CLASS_GTK_DRAWINGAREA,	SIGNAL_EXPOSE_EVENT,		TRUE,	"( GtkWidget *widget, GdkEventExpose *event, gpointer user_data )" },
{ CLASS_GTK_DRAWINGAREA,	SIGNAL_MOTION_NOTIFY_EVENT,	TRUE,	"( GtkWidget *drawingarea, GdkEventMotion *event, gpointer user_data )" },
{ CLASS_GTK_DRAWINGAREA,	SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_DRAWINGAREA,	SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_DRAWINGAREA : " },

{ CLASS_GTK_ENTRY,		SIGNAL_CHANGED,			FALSE,	"( GtkEditable *editable, gpointer user_data )" },
{ CLASS_GTK_ENTRY,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_ENTRY,		SIGNAL_ACTIVATE,		FALSE,	"( GtkEntry *editable, gpointer data )" },
{ CLASS_GTK_ENTRY,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_ENTRY :" },

{ CLASS_GTK_EVENTBOX,		SIGNAL_ENTER_NOTIFY_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventCrossing *event, gpointer user_data )" },
{ CLASS_GTK_EVENTBOX,		SIGNAL_LEAVE_NOTIFY_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventCrossing *event, gpointer user_data )" },
{ CLASS_GTK_EVENTBOX,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_EVENTBOX,		SIGNAL_EVENT_AFTER,		FALSE,	"( GtkWidget *widget, GdkEvent *event, gpointer user_data )" },
{ CLASS_GTK_EVENTBOX,		SIGNAL_EVENT,			TRUE,	"( GtkWidget *widget, GdkEvent *event, gpointer user_data )" },
{ CLASS_GTK_EVENTBOX,		SIGNAL_EXPOSE_EVENT,		TRUE,	"( GtkWidget *widget, GdkEventExpose *event, gpointer user_data )" },
{ CLASS_GTK_EVENTBOX,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_EVENTBOX :" },

{ CLASS_GTK_EXPANDER,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_EXPANDER,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_EXPANDER :" },

{ CLASS_GTK_IMAGE,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_IMAGE,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_IMAGE :" },

{ CLASS_GTK_IMAGEMENUITEM,	SIGNAL_ACTIVATE,		FALSE,	"( GtkImageMenuItem *menuitem, gpointer user_data )" },
{ CLASS_GTK_IMAGEMENUITEM,	SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_IMAGEMENUITEM :" },

{ CLASS_GTK_FRAME,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_FRAME,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_FRAME :" },
	
{ CLASS_GTK_HBOX,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_HBOX,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_HBOX :" },

{ CLASS_GTK_LABEL,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_LABEL,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_LABEL :" },

{ CLASS_GTK_LINKBUTTON,		SIGNAL_CLICKED,			FALSE,	"( GtkLinkButton *button, gpointer user_data )" },
{ CLASS_GTK_LINKBUTTON,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_LINKBUTTON :" },

{ CLASS_GTK_MENUBAR,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_MENUBAR :" },

{ CLASS_GTK_MENUITEM,		SIGNAL_ACTIVATE,		FALSE,	"( GtkMenuItem *menuitem, gpointer user_data )" },
{ CLASS_GTK_MENUITEM,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_MENUITEM :" },

{ CLASS_GTK_MENU,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_MENUBAR :" },

{ CLASS_GTK_NOTEBOOK,		SIGNAL_SWITCH_PAGE,		FALSE,	"( GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data )" },
{ CLASS_GTK_NOTEBOOK,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_NOTEBOOK,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_NOTEBOOK :" },

{ CLASS_GTK_PROGRESSBAR,	SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_PROGRESSBAR,	SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_PROGRESSBAR :" },

{ CLASS_GTK_RADIOBUTTON,	SIGNAL_CLICKED,			FALSE,	"( GtkButton *button, gpointer user_data )" },
{ CLASS_GTK_RADIOBUTTON,	SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_RADIOBUTTON,	SIGNAL_TOGGLED,			FALSE,	"( GtkToggleButton *togglebutton, gpointer user_data )" },
{ CLASS_GTK_RADIOBUTTON,	SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_RADIOBUTTON :" },

{ CLASS_GTK_SEPARATORMENUITEM,	SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_SEPARATORMENUITEM :" },

{ CLASS_GTK_SCROLLEWINDOW,	SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_SCROLLEWINDOW,	SIGNAL_EVENT,			TRUE,	"( GtkWidget *widget, GdkEvent *event, gpointer user_data )" },
{ CLASS_GTK_SCROLLEWINDOW,	SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_SCROLLEWINDOW :" },

{ CLASS_GTK_SPINBUTTON,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_SPINBUTTON,		SIGNAL_CHANGED,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_SPINBUTTON,		SIGNAL_VALUE_CHANGED,		FALSE,	"( GtkSpinButton *spinbutton, gpointer user_data )" },
{ CLASS_GTK_SPINBUTTON,		SIGNAL_BUTTON_PRESS_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventButton *event, gpointer user_data )" },
{ CLASS_GTK_SPINBUTTON,		SIGNAL_BUTTON_RELEASE_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventButton *event, gpointer user_data )" },
{ CLASS_GTK_SPINBUTTON,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_SPINBUTTON :" },

{ CLASS_GTK_TABLE,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_TABLE,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_TABLE :" },

{ CLASS_GTK_TEXTVIEW,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
	// 
	// ADD WITH COMMENT
	// 
	// void changed_textview (GtkTextBuffer *textbuffer, gpointer user_data) { }
	// 
	// g_signal_connect((gpointer) gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget)), "changed", G_CALLBACK (changed_textview), NULL);
	// 
{ CLASS_GTK_TEXTVIEW,		SIGNAL_DRAGNDROP_RECEVEID,	FALSE,	"( GtkWidget *widget, GdkDragContext *drag_context, gint x, gint y, GtkSelectionData *data, guint info, guint time, gpointer user_data )" },
{ CLASS_GTK_TEXTVIEW,		SIGNAL_KEY_PRESS_EVENT,		TRUE,	"( GtkWidget *widget, GdkEventKey *event, gpointer user_data )" },
{ CLASS_GTK_TEXTVIEW,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_TEXTVIEW :" },

{ CLASS_GTK_TOGGLEBUTTON,	SIGNAL_ENTER_NOTIFY_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventCrossing *event, gpointer user_data )" },
{ CLASS_GTK_TOGGLEBUTTON,	SIGNAL_LEAVE_NOTIFY_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventCrossing *event, gpointer user_data )" },
{ CLASS_GTK_TOGGLEBUTTON,	SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_TOGGLEBUTTON,	SIGNAL_CLICKED,			FALSE,	"( GtkButton *button, gpointer user_data )" },
{ CLASS_GTK_TOGGLEBUTTON,	SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_TOGGLEBUTTON :" },

{ CLASS_GTK_VBOX,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_VBOX :" },

{ CLASS_GTK_VIEWPORT,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_VIEWPORT,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_VIEWPORT :" },

{ CLASS_GTK_WINDOW,		SIGNAL_DELETE_EVENT,		TRUE,	"( GtkWidget *widget, GdkEvent *event, gpointer user_data )" },
{ CLASS_GTK_WINDOW,		SIGNAL_DESTROY_EVENT,		TRUE,	"( GtkWidget *widget, GdkEvent *event, gpointer user_data )" },
{ CLASS_GTK_WINDOW,		SIGNAL_EVENT,			TRUE,	"( GtkWidget *widget, GdkEvent *event, gpointer user_data )" },
{ CLASS_GTK_WINDOW,		SIGNAL_DESTROY,			FALSE,	"( GtkObject *object, gpointer user_data )" },
{ CLASS_GTK_WINDOW,		SIGNAL_KEY_PRESS_EVENT,		TRUE,	"( GtkWidget *widget, GdkEventKey *kevent, gpointer user_data )" },
{ CLASS_GTK_WINDOW,		SIGNAL_KEY_RELEASE_EVENT,	TRUE,	"( GtkWidget *widget, GdkEventKey *kevent, gpointer user_data )" },
{ CLASS_GTK_WINDOW,		SIGNAL_REALIZE,			FALSE,	"( GtkWidget *widget, gpointer user_data )" },
{ CLASS_GTK_WINDOW,		SIGNAL_NONE,			FALSE,	"// UNDEFINED : CLASS_GTK_WINDOW :" },

{ -1,				-1,				FALSE,	"" }
};


// 
// 
TYPE_CLASS Proto_get_type_class (gchar *p_NameClass)
{
	if (!strcmp(p_NameClass, "GtkAlignment"))		return (CLASS_GTK_ALIGMENT);
	else if (!strcmp(p_NameClass, "GtkAboutDialog"))	return (CLASS_GTK_ABOUTDIALOG);
	else if (!strcmp(p_NameClass, "GtkButton"))		return (CLASS_GTK_BUTTON);
	else if (!strcmp(p_NameClass, "GtkCheckButton"))	return (CLASS_GTK_CHECKBUTTON);
	else if (!strcmp(p_NameClass, "GtkComboBox"))		return (CLASS_GTK_COMBOBOX);
	else if (!strcmp(p_NameClass, "GtkComboBoxEntry"))	return (CLASS_GTK_COMBOBOXENTRY);
	else if (!strcmp(p_NameClass, "GtkDialog"))		return (CLASS_GTK_DIALOG);
	else if (!strcmp(p_NameClass, "GtkDrawingArea"))	return (CLASS_GTK_DRAWINGAREA);
	else if (!strcmp(p_NameClass, "GtkEntry"))		return (CLASS_GTK_ENTRY);
	else if (!strcmp(p_NameClass, "GtkEventBox"))		return (CLASS_GTK_EVENTBOX);
	else if (!strcmp(p_NameClass, "GtkExpander"))		return (CLASS_GTK_EXPANDER);
	else if (!strcmp(p_NameClass, "GtkImage"))		return (CLASS_GTK_IMAGE);
	else if (!strcmp(p_NameClass, "GtkImageMenuItem"))	return (CLASS_GTK_IMAGEMENUITEM);
	else if (!strcmp(p_NameClass, "GtkFrame"))		return (CLASS_GTK_FRAME);
	else if (!strcmp(p_NameClass, "GtkHBox"))		return (CLASS_GTK_HBOX);
	else if (!strcmp(p_NameClass, "GtkLabel"))		return (CLASS_GTK_LABEL);
	else if (!strcmp(p_NameClass, "GtkLinkButton"))		return (CLASS_GTK_LINKBUTTON);
	else if (!strcmp(p_NameClass, "GtkMenuBar"))		return (CLASS_GTK_MENUBAR);
	else if (!strcmp(p_NameClass, "GtkMenuItem"))		return (CLASS_GTK_MENUITEM);
	else if (!strcmp(p_NameClass, "GtkMenu"))		return (CLASS_GTK_MENU);
	else if (!strcmp(p_NameClass, "GtkNotebook"))		return (CLASS_GTK_NOTEBOOK);
	else if (!strcmp(p_NameClass, "GtkProgressBar"))	return (CLASS_GTK_PROGRESSBAR);
	else if (!strcmp(p_NameClass, "GtkRadioButton"))	return (CLASS_GTK_RADIOBUTTON);
	else if (!strcmp(p_NameClass, "GtkSeparatorMenuItem"))	return (CLASS_GTK_SEPARATORMENUITEM);
	else if (!strcmp(p_NameClass, "GtkScrolledWindow"))	return (CLASS_GTK_SCROLLEWINDOW);
	else if (!strcmp(p_NameClass, "GtkSpinButton"))		return (CLASS_GTK_SPINBUTTON);
	else if (!strcmp(p_NameClass, "GtkTable"))		return (CLASS_GTK_TABLE);
	else if (!strcmp(p_NameClass, "GtkTextView"))		return (CLASS_GTK_TEXTVIEW);
	else if (!strcmp(p_NameClass, "GtkToggleButton"))	return (CLASS_GTK_TOGGLEBUTTON);
	else if (!strcmp(p_NameClass, "GtkVBox"))		return (CLASS_GTK_VBOX);
	else if (!strcmp(p_NameClass, "GtkViewport"))		return (CLASS_GTK_VIEWPORT);
	else if (!strcmp(p_NameClass, "GtkWindow"))		return (CLASS_GTK_WINDOW);
	
	return (CLASS_NONE);
}
// 
// 
TYPE_SIGNAL Proto_get_type_signal (gchar *p_NameSignal)
{
	if (!strcmp(p_NameSignal, "activate"))			return (SIGNAL_ACTIVATE);
	else if (!strcmp(p_NameSignal, "button_press_event"))	return (SIGNAL_BUTTON_PRESS_EVENT);
	else if (!strcmp(p_NameSignal, "button_release_event"))	return (SIGNAL_BUTTON_RELEASE_EVENT);
	else if (!strcmp(p_NameSignal, "changed"))		return (SIGNAL_CHANGED);
	else if (!strcmp(p_NameSignal, "clicked"))		return (SIGNAL_CLICKED);
	else if (!strcmp(p_NameSignal, "close"))		return (SIGNAL_CLOSE);
	else if (!strcmp(p_NameSignal, "delete_event"))		return (SIGNAL_DELETE_EVENT);
	else if (!strcmp(p_NameSignal, "destroy_event"))	return (SIGNAL_DESTROY_EVENT);
	else if (!strcmp(p_NameSignal, "destroy"))		return (SIGNAL_DESTROY);
	else if (!strcmp(p_NameSignal, "enter_notify_event"))	return (SIGNAL_ENTER_NOTIFY_EVENT);
	else if (!strcmp(p_NameSignal, "event"))		return (SIGNAL_EVENT);
	else if (!strcmp(p_NameSignal, "event_after"))		return (SIGNAL_EVENT_AFTER);
	else if (!strcmp(p_NameSignal, "expose_event"))		return (SIGNAL_EXPOSE_EVENT);
	else if (!strcmp(p_NameSignal, "key_press_event"))	return (SIGNAL_KEY_PRESS_EVENT);
	else if (!strcmp(p_NameSignal, "key_release_event"))	return (SIGNAL_KEY_RELEASE_EVENT);
	else if (!strcmp(p_NameSignal, "leave_notify_event"))	return (SIGNAL_LEAVE_NOTIFY_EVENT);
	else if (!strcmp(p_NameSignal, "map_event"))		return (SIGNAL_MAP_EVENT);
	else if (!strcmp(p_NameSignal, "motion_notify_event"))	return (SIGNAL_MOTION_NOTIFY_EVENT);
	else if (!strcmp(p_NameSignal, "realize"))		return (SIGNAL_REALIZE);
	else if (!strcmp(p_NameSignal, "response"))		return (SIGNAL_RESPONSE);
	else if (!strcmp(p_NameSignal, "drag_data_received"))	return (SIGNAL_DRAGNDROP_RECEVEID);
	else if (!strcmp(p_NameSignal, "toggled"))		return (SIGNAL_TOGGLED);
	else if (!strcmp(p_NameSignal, "switch_page"))		return (SIGNAL_SWITCH_PAGE);
	else if (!strcmp(p_NameSignal, "value_changed"))	return (SIGNAL_VALUE_CHANGED);
	
	return (SIGNAL_NONE);
}
// 
// 
gboolean Proto_alloc_object (gchar *p_str_object)
{
	STRUCT_CLASS	*StructClass = NULL;
	gchar		*PtrBegin = NULL;
	
	// PRINT_FUNC_LF();
	
	// <object class="GtkWindow" id="window_main">
	
	if (NULL == (StructClass = (STRUCT_CLASS *)g_malloc0 (sizeof (STRUCT_CLASS)))) {
		g_print ("ERREUR ALLOCATION POUR CLASS !!!\n");
		return FALSE;
	}
	
	// <object class="GtkWindow" id="window_main">
	// GtkWindow" id="window_main">
	
	PtrBegin = strchr (p_str_object, '"');
	PtrBegin ++;
	StructClass->Object = g_strdup (PtrBegin);
	PtrBegin = strchr (StructClass->Object, '"');
	*PtrBegin = '\0';
	
	// GET TYPE OF CLASSE
	StructClass->TypeClass = Proto_get_type_class (StructClass->Object);

	// <object class="GtkWindow" id="window_main">
	// window_main">
	
	PtrBegin = strstr (p_str_object, "id=");
	PtrBegin = strchr (PtrBegin, '"');
	PtrBegin ++;
	StructClass->Id     = g_strdup (PtrBegin);
	PtrBegin = strchr (StructClass->Id, '"');
	*PtrBegin = '\0';
	
	// SET ALLOCATE TO GLIST
	ListClass = g_list_append (ListClass, StructClass);
	
	return TRUE;
}
// 
// 
gboolean Proto_is_dupplicate (gchar *Str)
{
	GList		*ListC = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	GList		*ListS = NULL;
	STRUCT_SIGNAL	*StructSignal = NULL;
	
	ListC = g_list_first (ListClass);
	while (ListC) {
		if (NULL != (StructClass = (STRUCT_CLASS *)ListC->data)) {
			ListS = g_list_first (StructClass->ListSignal);
			while (ListS) {
				if (NULL != (StructSignal = (STRUCT_SIGNAL *)ListS->data)) {
					if (0 == strcmp (StructSignal->Handler, Str)) {
						// g_print (" -> DUPPLICATE IS -> %s\n", Str);
						return (TRUE);
					}
				}
				ListS = g_list_next (ListS);
			}
		}
		ListC = g_list_next (ListC);
	}
	return (FALSE);
}
// 
// 
gboolean Proto_alloc_signal (gchar *p_str_signal)
{
	STRUCT_SIGNAL	*StructSignal = NULL;
	GList		*List = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	gchar		*PtrBegin = NULL;
	
	// PRINT_FUNC_LF();
	
	// <signal name="delete_event" handler="on_aboutdialog_basebuild_delete_event"/>
	
	if (NULL == (StructSignal = (STRUCT_SIGNAL *)g_malloc0 (sizeof (STRUCT_SIGNAL)))) {
		g_print ("ERREUR ALLOCATION POUR SIGNAL !!!\n");
		return FALSE;
	}
	
	// <signal name="delete_event" handler="on_aboutdialog_basebuild_delete_event"/>
	// delete_event" handler="on_aboutdialog_basebuild_delete_event"/>
	
	PtrBegin = strchr (p_str_signal, '"');
	PtrBegin ++;
	StructSignal->Signal  = g_strdup (PtrBegin);
	PtrBegin = strchr (StructSignal->Signal, '"');
	*PtrBegin = '\0';
	
	// GET TYPE OF SIGNAL
	StructSignal->TypeSignal = Proto_get_type_signal (StructSignal->Signal);

	// <signal name="delete_event" handler="on_aboutdialog_basebuild_delete_event"/>
	// on_aboutdialog_basebuild_delete_event"/>
	
	PtrBegin = strstr (p_str_signal, "handler=");
	PtrBegin = strchr (PtrBegin, '"');
	PtrBegin ++;
	StructSignal->Handler = g_strdup (PtrBegin);
	PtrBegin = strchr (StructSignal->Handler, '"');
	*PtrBegin = '\0';
	
	// SEARCH GLIST
	List =  g_list_last (ListClass);
	StructClass = (STRUCT_CLASS *)List->data;
	
	// DUPPLICATE ?
	// OR
	// IF THE FUNCTION OF REFERENCE OF THE SIGNAL IS NOT A FUNCTION gtk_
	// Example:
	// 	<signal name="delete_event" handler="gtk_main_quit"/>
	// 
	if (TRUE == Proto_is_dupplicate (StructSignal->Handler) || 0 == strncmp( StructSignal->Handler, "gtk_", 4 )) {
		g_free (StructSignal->Signal);
		g_free (StructSignal->Handler);
		g_free (StructSignal);
		StructSignal = NULL;
	}
	// SET ALLOCATE TO GLIST
	else {
		StructClass->ListSignal = g_list_last (StructClass->ListSignal);
		StructClass->ListSignal = g_list_append (StructClass->ListSignal, StructSignal);
	}
	return TRUE;
}
// 
// 
void Proto_print (void)
{
	GList		*ListC = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	GList		*ListS = NULL;
	STRUCT_SIGNAL	*StructSignal = NULL;
	
	// PRINT_FUNC_LF();
	
	ListC = g_list_first (ListClass);
	while (ListC) {
		if (NULL != (StructClass = (STRUCT_CLASS *)ListC->data)) {
			g_print ("StructClass->Object = %s     ", StructClass->Object);
			g_print ("StructClass->Id = %s", StructClass->Id);
			g_print ("\n");
			
			ListS = g_list_first (StructClass->ListSignal);
			while (ListS) {
				if (NULL != (StructSignal = (STRUCT_SIGNAL *)ListS->data)) {
					g_print ("StructSignal->Signal = %s     ", StructSignal->Signal);
					g_print ("StructSignal->Handler = %s", StructSignal->Handler);
					g_print ("\n");
				}
				ListS = g_list_next (ListS);
			}
		}
		ListC = g_list_next (ListC);
	}
	g_print ("\n");
}
// 
// 
void Proto_remove (void)
{
	GList		*ListC = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	GList		*ListS = NULL;
	STRUCT_SIGNAL	*StructSignal = NULL;
	gint		NbrClass = 0;
	gint		NbrSignal = 0;
	
	PRINT_FUNC_LF();
	
	ListC = g_list_first (ListClass);
	while (ListC) {
		if (NULL != (StructClass = (STRUCT_CLASS *)ListC->data)) {
			ListS = g_list_first (StructClass->ListSignal);
			while (ListS) {
				if (NULL != (StructSignal = (STRUCT_SIGNAL *)ListS->data)) {
					g_free (StructSignal->Signal);
					g_free (StructSignal->Handler);
					g_free (StructSignal);
					StructSignal = ListS->data = NULL;
					
					NbrSignal ++;
				}
				ListS = g_list_next (ListS);
			}
			g_list_free (StructClass->ListSignal);
			StructClass->ListSignal = NULL;
			
			g_free (StructClass->Object);
			g_free (StructClass->Id);
			g_free (StructClass);
			StructClass = ListC->data = NULL;
			
			NbrClass ++;
		}
		ListC = g_list_next (ListC);
	}
	g_list_free (ListClass);
	ListClass = NULL;
	
	g_print ("\tRemove NbrClass  = %d\n", NbrClass);
	g_print ("\tRemove NbrSignal = %d\n", NbrSignal);
	g_print ("\n");

	if (NULL != VarProto.GstrMain) {
		g_string_free (VarProto.GstrMain, TRUE);
		VarProto.GstrMain = NULL;
	}
	// 
	// REPORT DE CETTE PARTIE DEPUIS:
	//	static void build_pthread_clicked (void *arg)
	// 
	// if (NULL != VarProto.GstrTranslate) {
	// 	g_string_free (VarProto.GstrTranslate, TRUE);
	// 	VarProto.GstrTranslate = NULL;
	// }
	if (NULL != VarProto.PathNameFileGlade) {
		g_free (VarProto.PathNameFileGlade);
		VarProto.PathNameFileGlade = NULL;
	}
	VarProto.BoolOk = FALSE;
	VarProto.BoolTranslateOk = FALSE;
}
// 
// 
PROTO_STRUCT *Proto_get( TYPE_CLASS p_TypeClass, TYPE_SIGNAL p_TypeSignal )
{
	gint	Cpt = 0;
	
	// PRINT_FUNC_LF();
	
	while( ProtoStruct[ Cpt ].TypeClass != -1 ) {
		if( ProtoStruct[ Cpt ].TypeClass == p_TypeClass && ProtoStruct[ Cpt ].TypeSignal == p_TypeSignal ) {
			return( &ProtoStruct[ Cpt ] );
		}
		Cpt ++;
	}
	return( NULL );
}
// 
// 
void Proto_make (void)
{
	GList		*ListC = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	GList		*ListS = NULL;
	STRUCT_SIGNAL	*StructSignal = NULL;
	gchar		*StrClassGtkWindow = NULL;
	PROTO_STRUCT	*PtrProto = NULL;
	
	PRINT_FUNC_LF();
	
	VarProto.GstrMain = g_string_new (NULL);
	
	ListC = g_list_first (ListClass);
	while (ListC) {
		if (NULL != (StructClass = (STRUCT_CLASS *)ListC->data)) {
					 	
			ListS = g_list_first (StructClass->ListSignal);
			while (ListS) {
				if (NULL != (StructSignal = (STRUCT_SIGNAL *)ListS->data)) {

					// SEARCH StructClass->TypeClass and StructSignal->TypeSignal
					// 
					if( NULL != ( PtrProto = Proto_get( StructClass->TypeClass, StructSignal->TypeSignal ))) {
						
						if( CLASS_NONE == StructClass->TypeClass ) {
					
							g_string_append_printf( VarProto.GstrMain, "%s StructSignal->Signal = %s   Object = %s   Handler = %s\n", PtrProto->ParamFunction, StructSignal->Signal, StructClass->Object, StructSignal->Handler );
						}
						else if( SIGNAL_NONE == StructSignal->TypeSignal ) {
					
							g_string_append_printf( VarProto.GstrMain, "%s StructSignal->Signal = %s\n", PtrProto->ParamFunction, StructSignal->Signal );
						}
						else {
					
							if( CLASS_GTK_WINDOW == StructClass->TypeClass || CLASS_GTK_DIALOG == StructClass->TypeClass || CLASS_GTK_ABOUTDIALOG == StructClass->TypeClass ) {
								
								if (NULL != StrClassGtkWindow && 0 != strcmp (StrClassGtkWindow, StructClass->Id)) {
									g_free (StrClassGtkWindow);
									StrClassGtkWindow = NULL;
								}
							
								if (NULL == StrClassGtkWindow) {
									StrClassGtkWindow = g_strdup (StructClass->Id);
									g_string_append_printf (VarProto.GstrMain, "// ---------------------------------------------\n");
									g_string_append_printf (VarProto.GstrMain, "// StructClass->Id = %s\n", StrClassGtkWindow);
									g_string_append_printf (VarProto.GstrMain, "// ---------------------------------------------\n");
								}
							}

							if( TRUE == PtrProto->ReturnBoolean)  {
						
								g_string_append_printf (VarProto.GstrMain, "gboolean %s%s\n", StructSignal->Handler, PtrProto->ParamFunction);
						
								if( CLASS_GTK_WINDOW == StructClass->TypeClass && 
									  ( SIGNAL_DELETE_EVENT == StructSignal->TypeSignal || SIGNAL_DESTROY_EVENT == StructSignal->TypeSignal )) {
									  
									 g_string_append_printf (VarProto.GstrMain, "{\n\tgtk_main_quit ();\n\treturn( FALSE );\n}\n");
								}
								else if(  CLASS_GTK_WINDOW == StructClass->TypeClass && SIGNAL_KEY_PRESS_EVENT == StructSignal->TypeSignal ) {
									g_string_append_printf (VarProto.GstrMain, "// FONCTION SIGNAL_KEY_PRESS_EVENT\n");
							// *****************
									// g_string_append_printf (VarProto.GstrMain, "// \n");
									// g_string_append_printf (VarProto.GstrMain, "// \n");
									// g_string_append_printf (VarProto.GstrMain, "gboolean on_wind_main_key_press_event( GtkWidget *widget, GdkEventKey *kevent, gpointer user_data )\n");
									g_string_append_printf (VarProto.GstrMain, "{\n");
									g_string_append_printf (VarProto.GstrMain, "	keys.BoolGDKPress = TRUE;\n");
									g_string_append_printf (VarProto.GstrMain, "	keys.keyval       = kevent->keyval;\n");
									g_string_append_printf (VarProto.GstrMain, "	\n");
									g_string_append_printf (VarProto.GstrMain, "	if( kevent->keyval == GDK_Control_L || kevent->keyval == GDK_Control_R ) {\n");
									g_string_append_printf (VarProto.GstrMain, "		keys.BoolGDK_Control_L_R = TRUE;\n");
									g_string_append_printf (VarProto.GstrMain, "	}\n");
									g_string_append_printf (VarProto.GstrMain, "	else if( kevent->state == 20 || kevent->state == 21 ) {\n");
									g_string_append_printf (VarProto.GstrMain, "		if( kevent->keyval == 65 || kevent->keyval == 97 ) {\n");
									g_string_append_printf (VarProto.GstrMain, "			keys.BoolGDK_Control_A = TRUE;\n");
									g_string_append_printf (VarProto.GstrMain, "		}\n");
									g_string_append_printf (VarProto.GstrMain, "	}\n");
									g_string_append_printf (VarProto.GstrMain, "	\n");
									g_string_append_printf (VarProto.GstrMain, "	return FALSE;\n");
									g_string_append_printf (VarProto.GstrMain, "}\n");
							// *****************
								}
								else if(  CLASS_GTK_WINDOW == StructClass->TypeClass && SIGNAL_KEY_RELEASE_EVENT == StructSignal->TypeSignal ) {
									g_string_append_printf (VarProto.GstrMain, "// FONCTION SIGNAL_KEY_RELEASE_EVENT\n");
							// *****************
									// g_string_append_printf (VarProto.GstrMain, "// \n");
									// g_string_append_printf (VarProto.GstrMain, "// \n");
									// g_string_append_printf (VarProto.GstrMain, "gboolean on_wind_main_key_release_event( GtkWidget *widget, GdkEventKey *kevent, gpointer user_data )\n");
									g_string_append_printf (VarProto.GstrMain, "{\n");
									g_string_append_printf (VarProto.GstrMain, "	keys.BoolGDKPress        = FALSE;\n");
									g_string_append_printf (VarProto.GstrMain, "	keys.BoolGDK_Control_L_R = FALSE;\n");
									g_string_append_printf (VarProto.GstrMain, "	keys.BoolGDK_Control_A   = FALSE;\n");
									g_string_append_printf (VarProto.GstrMain, "	keys.keyval              = 0;\n");
									g_string_append_printf (VarProto.GstrMain, "	\n");
									g_string_append_printf (VarProto.GstrMain, "	return FALSE;\n");
									g_string_append_printf (VarProto.GstrMain, "}\n");
							// *****************
								}
								else {
									g_string_append_printf (VarProto.GstrMain, "{\n\treturn( FALSE );\n}\n");
								}
						
							}
							else {
								g_string_append_printf (VarProto.GstrMain, "void %s%s\n{\n}\n", StructSignal->Handler, PtrProto->ParamFunction);
								
								if( CLASS_GTK_TEXTVIEW == StructClass->TypeClass && SIGNAL_REALIZE == StructSignal->TypeSignal ) {
									g_string_append( VarProto.GstrMain, "\t// SIGNAL_CHANGED\n" );
									g_string_append( VarProto.GstrMain, "\t// void changed_textview (GtkTextBuffer *textbuffer, gpointer user_data) { }\n" );
									g_string_append( VarProto.GstrMain, "\t// IN REALIZE:\n" );
									g_string_append( VarProto.GstrMain, "\t// g_signal_connect((gpointer) gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget)), \"changed\", G_CALLBACK (changed_textview), NULL);\n" );
								}
							}
						}
					}
				}
				ListS = g_list_next (ListS);
			}
		}
		
		ListC = g_list_next (ListC);
	}
	if (NULL != StrClassGtkWindow) {
		g_free (StrClassGtkWindow);
		StrClassGtkWindow = NULL;
	}
	g_print ("\n");
}
// 
// TRUE = ok
// FALSE
//	LE FICHIER [ %s ] N'EXISTE PAS
//	ERREUR ALLOCATION DU BUFFER
//	ERREUR A L'OUVERTURE DU FICHIER
gboolean Proto_init (gchar *PathnameFileGlade)
{
	FILE		*fp = NULL;
	char		*buf = NULL;
	size_t   	Size = libutils_get_size_file (PathnameFileGlade);
	gchar		**Larrbuf = NULL;
	gint		i;
	gboolean	BoolAllocOk = TRUE;
	
	// PRINT_FUNC_LF();
	
	// FILE EXIST
	if (FALSE == libutils_test_file_exist (PathnameFileGlade)) {
		g_print ("LE FICHIER [ %s ] N'EXISTE PAS !!!\n", PathnameFileGlade);
		return FALSE;
	}	
	// BUFFER DU FICHIER
	if (NULL == (buf = (char *)malloc (sizeof(char) * (Size + 10)))) {
		g_print ("ERREUR ALLOCATION DU BUFFER !!!\n");
		return FALSE;
	}
	// OUVERTURE DU FICHIER
	if ((fp = fopen (PathnameFileGlade, "r")) == NULL) {
		printf ("\nERREUR A L'OUVERTURE DU FICHIER: %s\n\n", PathnameFileGlade);
		g_free( buf ); buf = NULL;
		return FALSE;
	}

	// STOCKE LE NOM DU FICHIER POUR ANALYSE
	VarProto.PathNameFileGlade = g_strdup (PathnameFileGlade);

	// LECTURE DU FICHIER DANS: buf
	fread (buf, 1, Size, fp);
	// FERMETURE DU FICHIER
	fclose (fp);
	// BUFFER EN LIGNES POUR: Larrbuf DEPUIS: buf
	Larrbuf = g_strsplit(buf, "\n", 0);
	// REMOVE: buf
	g_free (buf);
	buf = NULL;
	
	// 
	VarProto.GstrTranslate = g_string_new (NULL);
	
	// LECTURE DE CHAQUE LIGNE DE: Larrbuf
	for (i=0; Larrbuf[i]; i++) {
		
		if (strstr (Larrbuf[i], "<object class=") ||		// NEW GLADE VERSION
			strstr (Larrbuf[i], "<widget class=")) {	// OLD GLADE VERSION
			BoolAllocOk = Proto_alloc_object (Larrbuf[i]);
		}
		else if (strstr (Larrbuf[i], "<signal name=")) {
			BoolAllocOk = Proto_alloc_signal (Larrbuf[i]);
		}
		
		if (FALSE == BoolAllocOk) {
			g_print ("PROBLEME D'ALLOCATION MEMOIRE !!!\n");
			g_print ("\tJE QUITTE LA BOUCLE DE RECHERCHE\n");
			break;
		}
	}

	// REMOVE: Larrbuf
	g_strfreev(Larrbuf);
	Larrbuf = NULL;
	
	// Proto_print ();
	Proto_make ();
	
	VarProto.BoolOk = TRUE;
	
	return TRUE;
}
// 
// 
void Proto_copy_glade_file (gchar *Src, gchar *Dest)
{
	libutils_copy_src_to_dest (Src, Dest);
}
// 
// 
gboolean Proto_init_is_ok (void)
{
	return (VarProto.BoolOk);
}
// 
// 
GString *Proto_get_buf_main (void)
{
	return (VarProto.GstrMain);
}
// 
// 
GString *Proto_get_buf_translate (void)
{
	return (VarProto.GstrTranslate);
}
// 
// 
gchar *Proto_get_id (void)
{
	GList		*List = NULL;
	STRUCT_CLASS	*StructClass = NULL;
	
	List = g_list_first (ListClass);
	if (NULL != (StructClass = (STRUCT_CLASS *)List->data)) {
		return (StructClass->Id);
	}
	return (NULL);
}

















