 /*
 * file      : proto.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 - 2011 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 * 
 * This file is part of BASEBUILD.
 * 
 * BASEBUILD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * BASEBUILD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with BASEBUILD.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>

#include "global.h"
#include "../libbasebuild/libbasebuild.h"
#include "build.h"
#include "view.h"
#include "proto.h"


extern VAR_BUILD VarBuild;
extern VAR_PROTO VarProto;



// The text contains accents
// 
gboolean ProtoTranslate_contains_accents (void)
{
	gchar	*Ptr = NULL;
	
	if (NULL != Proto_get_buf_translate ()) {
		for (Ptr = VarProto.GstrTranslate->str; *Ptr; Ptr ++) {
			if (*Ptr < 0) return (TRUE);
		}
	}
	return (FALSE);
}
// 
// 
void ProtoTranslate_alloc_begin (void)
{
	
	if (NULL != Proto_get_buf_translate ()) {
		g_string_append_printf (VarProto.GstrTranslate, "/* \n");
		g_string_append_printf (VarProto.GstrTranslate, " * translate.c\n");
		g_string_append_printf (VarProto.GstrTranslate, " * \n");
		g_string_append_printf (VarProto.GstrTranslate, " * Traduction des chaines du fichier *.glade\n");
		g_string_append_printf (VarProto.GstrTranslate, " * Translate string of *.glade file\n");
		g_string_append_printf (VarProto.GstrTranslate, " * \n");
		g_string_append_printf (VarProto.GstrTranslate, " */\n\n");
		g_string_append_printf (VarProto.GstrTranslate, "#ifdef HAVE_CONFIG_H\n");
		g_string_append_printf (VarProto.GstrTranslate, "	#include \"../config.h\"\n");
		g_string_append_printf (VarProto.GstrTranslate, "#endif\n");
		g_string_append_printf (VarProto.GstrTranslate, "\n");
		g_string_append_printf (VarProto.GstrTranslate, "#ifdef ENABLE_NLS\n");
		g_string_append_printf (VarProto.GstrTranslate, "	#include <libintl.h>\n");
		g_string_append_printf (VarProto.GstrTranslate, "	#define _(String) gettext (String)\n");
		g_string_append_printf (VarProto.GstrTranslate, "#endif\n");
		g_string_append_printf (VarProto.GstrTranslate, "\n");
		g_string_append_printf (VarProto.GstrTranslate, "#include <gtk/gtk.h>\n");
		g_string_append_printf (VarProto.GstrTranslate, "\n");
		g_string_append_printf (VarProto.GstrTranslate, "#ifdef ENABLE_STATIC_LIBRARY\n");
		g_string_append_printf (VarProto.GstrTranslate, "	#include \"../%s/lib.h\"\n", VarBuild.NameLib != NULL ? VarBuild.NameLib : "lib");
		g_string_append_printf (VarProto.GstrTranslate, "#endif\n");
		g_string_append_printf (VarProto.GstrTranslate, "\n");
		g_string_append_printf (VarProto.GstrTranslate, "void translate_glade (void)\n");
		g_string_append_printf (VarProto.GstrTranslate, "{\n");
		g_string_append_printf (VarProto.GstrTranslate, "	typedef struct {\n");
		g_string_append_printf (VarProto.GstrTranslate, "		gchar	*string;\n");
		g_string_append_printf (VarProto.GstrTranslate, "	} TRANS;\n");
		g_string_append_printf (VarProto.GstrTranslate, "\n");
		g_string_append_printf (VarProto.GstrTranslate, "TRANS trans[] = {\n");
		g_string_append_printf (VarProto.GstrTranslate, "\n");
	}
}
// 
// 
void ProtoTranslate_alloc_end (void)
{
	GString	*GstrTranslate = NULL;
	
	if (NULL != (GstrTranslate = Proto_get_buf_translate ())) {
		
		gchar	*Ptr = GstrTranslate->str;
		
		while (*Ptr) Ptr ++;
		while (*Ptr != ',') Ptr --;
		*Ptr = '\n';
		g_string_append_printf (VarProto.GstrTranslate, "};\n");
		g_string_append_printf (VarProto.GstrTranslate, "\tif (*trans [ 0 ] . string);\n");
		g_string_append_printf (VarProto.GstrTranslate, "}\n");
		g_string_append_printf (VarProto.GstrTranslate, "\n");
		GstrTranslate = NULL;
	}
}
// 
// 
gboolean ProtoTranslate_alloc (gchar *p_str_translate)
{
/*
	<property name="label" translatable="yes">
&lt;b&gt;&lt;i&gt;Pour installer les programmes externes requis,
veuillez utiliser l'installateur de votre distribution Gnu/Linux.&lt;/i&gt;&lt;/b&gt;
</property>
	
	<property name="label" translatable="yes">&lt;b&gt; Informations &lt;/b&gt;</property>
        
        <col id="0" translatable="yes">Video - Theora + Vorbis (OGG)</col>


	&lt;
		<
		else if ((*Ptr == '&') && (*(Ptr +1) == 'l') && (*(Ptr +2) == 't') && (*(Ptr +3) == ';')) {
	&gt;
		>
		else if ((*Ptr == '&') && (*(Ptr +1) == 'g') && (*(Ptr +2) == 't') && (*(Ptr +3) == ';')) {
*/
	gchar	*Ptr = NULL;
	gchar	*PtrEnd = NULL;
	
	VarProto.BoolTranslateOk = TRUE;
		
	// CHERCHE LE POINTEUR DE DEBUT POUR: Ptr
	if (NULL != (Ptr = strstr (p_str_translate, "translatable="))) {
		// RECHERCHE DE:   ">
		while (*Ptr != '>') Ptr ++;
		Ptr ++;
		g_string_append_printf (VarProto.GstrTranslate, "{ _(\"");
	}
	else {
		// SINON Ptr POINTE AU DEBUT DE LA CHAINE
		Ptr = p_str_translate;
	}
	// CHERCHE LE POINTEUR DE FIN: PtrEnd
	// if (NULL != (PtrEnd = strstr (Ptr, "</property>"))) {
	if (NULL != (PtrEnd = strstr (Ptr, "</"))) {
		// AFFICHE DEPUIS: Ptr JUSQU'A: PtrEnd
		while (Ptr < PtrEnd) {
			if (*Ptr == '"') {
				g_string_append_printf (VarProto.GstrTranslate, "\\\"");
			}
			else if ((PtrEnd - Ptr >= 4) && ((*Ptr == '&') && (*(Ptr +1) == 'l') && (*(Ptr +2) == 't') && (*(Ptr +3) == ';'))) {
				g_string_append_printf (VarProto.GstrTranslate, "<");
				Ptr += 3;
			}
			else if ((PtrEnd - Ptr >= 4) && ((*Ptr == '&') && (*(Ptr +1) == 'g') && (*(Ptr +2) == 't') && (*(Ptr +3) == ';'))) {
				g_string_append_printf (VarProto.GstrTranslate, ">");
				Ptr += 3;
			}
			else {
				g_string_append_printf (VarProto.GstrTranslate, "%c", *Ptr);
			}
			Ptr ++;
		}
		// MARQUE LA FIN DE LA RECHERCHE
		VarProto.BoolTranslateOk = FALSE;
		// g_print("\") },\n");
		g_string_append_printf (VarProto.GstrTranslate, "\") },\n");
	}
	else {
		// SET PtrEnd
		for (PtrEnd = Ptr; *PtrEnd; PtrEnd ++);
		// AFFICHE DEPUIS: Ptr JUSQU'A LA FIN DE LA CHAINE
		while (*Ptr) {
			if (*Ptr == '"') {
				g_string_append_printf (VarProto.GstrTranslate, "\\\"");
			}
			else if ((PtrEnd - Ptr >= 4) && ((*Ptr == '&') && (*(Ptr +1) == 'l') && (*(Ptr +2) == 't') && (*(Ptr +3) == ';'))) {
				g_string_append_printf (VarProto.GstrTranslate, "<");
				Ptr += 3;
			}
			else if ((PtrEnd - Ptr >= 4) && ((*Ptr == '&') && (*(Ptr +1) == 'g') && (*(Ptr +2) == 't') && (*(Ptr +3) == ';'))) {
				g_string_append_printf (VarProto.GstrTranslate, ">");
				Ptr += 3;
			}
			else {
				g_string_append_printf (VarProto.GstrTranslate, "%c", *Ptr);
			}
			Ptr ++;
		}
		g_string_append_printf (VarProto.GstrTranslate, "\\n");
	}
	
	return TRUE;
}
// 
// TRUE = ok
// FALSE
//	LE FICHIER [ %s ] N'EXISTE PAS
//	ERREUR ALLOCATION DU BUFFER
//	ERREUR A L'OUVERTURE DU FICHIER
// 
gboolean ProtoTranslate_init (gchar *PathnameFileGlade)
{
	FILE		*fp = NULL;
	char		*buf = NULL;
	size_t   	Size = libutils_get_size_file (PathnameFileGlade);
	gchar		**Larrbuf = NULL;
	gint		i;
	gboolean	BoolAllocOk = TRUE;
	
	PRINT_FUNC_LF();
	
	// FILE EXIST
	if (FALSE == libutils_test_file_exist (PathnameFileGlade)) {
		g_print ("LE FICHIER [ %s ] N'EXISTE PAS !!!\n", PathnameFileGlade);
		return FALSE;
	}	
	// BUFFER DU FICHIER
	if (NULL == (buf = (char *)malloc (sizeof(char) * (Size + 10)))) {
		g_print ("ERREUR ALLOCATION DU BUFFER !!!\n");
		return FALSE;
	}
	// OUVERTURE DU FICHIER
	if ((fp = fopen (PathnameFileGlade, "r")) == NULL) {
		printf ("\nERREUR A L'OUVERTURE DU FICHIER: %s\n\n", PathnameFileGlade);
		return FALSE;
	}

	// STOCKE LE NOM DU FICHIER POUR ANALYSE
	// VarProto.PathNameFileGlade = g_strdup (PathnameFileGlade);

	// LECTURE DU FICHIER DANS: buf
	fread (buf, 1, Size, fp);
	// FERMETURE DU FICHIER
	fclose (fp);
	// BUFFER EN LIGNES POUR: Larrbuf DEPUIS: buf
	Larrbuf = g_strsplit(buf, "\n", 0);
	// REMOVE: buf
	g_free (buf);
	buf = NULL;
	
	// CE BUFFER EST UTILE POUR L'AFFICHAGE DE LA PARTIE translate DANS LE TREVIEW
	if (NULL != VarProto.GstrTranslate) {
		g_string_free (VarProto.GstrTranslate, TRUE);
		VarProto.GstrTranslate = NULL;
	}
	// 
	VarProto.GstrTranslate = g_string_new (NULL);
	// 
	ProtoTranslate_alloc_begin ();
	
	// LECTURE DE CHAQUE LIGNE DE: Larrbuf
	for (i=0; Larrbuf[i]; i++) {
		
		if (strstr (Larrbuf[i], "translatable=")) {
			BoolAllocOk = ProtoTranslate_alloc (Larrbuf[i]);
		}
		else if (TRUE == VarProto.BoolTranslateOk) {
			BoolAllocOk = ProtoTranslate_alloc (Larrbuf[i]);
		}
		
		if (FALSE == BoolAllocOk) {
			g_print ("PROBLEME D'ALLOCATION MEMOIRE !!!\n");
			g_print ("\tJE QUITTE LA BOUCLE DE RECHERCHE\n");
			break;
		}
	}

	// 
	ProtoTranslate_alloc_end ();

	// REMOVE: Larrbuf
	g_strfreev(Larrbuf);
	Larrbuf = NULL;
	
	// g_print ("VarProto.GstrTranslate = \n%s\n", VarProto.GstrTranslate->str);
	
	return TRUE;
}
// 
// 
void ProtoTranslate_to_textview (void)
{
	PRINT_FUNC_LF();
	
	if (NULL != Proto_get_buf_translate ()) {
		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_dossiers")), 3);
		wiew_without_threads ();
		wiew_set_text_translate (VarProto.GstrTranslate->str);
	}
}












